summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJames Meyer <james.meyer@operamail.com>2012-02-14 15:40:11 (GMT)
committerJames Meyer <james.meyer@operamail.com>2012-02-14 15:40:11 (GMT)
commit267541d3a452f6c09af3596c3a3ad9598921771f (patch)
treed1ddc5fe4cb1895be0206d476ac0a66073e14989
parent1433894bbf86f6641791cfc9bcc25ceb9eaaed63 (diff)
downloadlinhes_dev-267541d3a452f6c09af3596c3a3ad9598921771f.zip
fix kmsync for new location on replacment server.
-rwxr-xr-xbuild_tools/bin/kmsync.sh39
-rwxr-xr-xbuild_tools/bin/update_db_repo.sh2
2 files changed, 21 insertions, 20 deletions
diff --git a/build_tools/bin/update_db_repo.sh b/build_tools/bin/update_db_repo.sh
index 3cc221e..4434a12 100755
--- a/build_tools/bin/update_db_repo.sh
+++ b/build_tools/bin/update_db_repo.sh
@@ -16,7 +16,7 @@ REPO=$2
echo " --------------------------"
echo "updating database for $REPO"
echo " --------------------------"
-pwd
+#pwd
#forcefully remove the old db to start clean
rm -f $REPO.db.tar.gz
repo-add -q $REPO.db.tar.gz *.pkg.tar.*
diff --git a/build_tools/bin/kmsync.sh b/build_tools/bin/kmsync.sh
index ab1e1dc..42b001b 100755
--- a/build_tools/bin/kmsync.sh
+++ b/build_tools/bin/kmsync.sh
@@ -1,6 +1,6 @@
#!/bin/bash
#This script will create and synchronize a local package mirror with the repository (as defined below) on knoppmyth.net, it will also update the database.
#This script uses a shared account on knoppmyth.net. DO NOT change the account name
# and dont' ask for the password, instead setup ssh keys.
#
@@ -12,7 +12,8 @@ else
echo "couldn't find /etc/makepkg.conf"
fi
cwd=`dirname $0`
-REMOTE_DIR=/mount/repository/repo
+#REMOTE_DIR=/srv/www/repo
+REMOTE_DIR=/srv/www/repo
DOCROOT=/data/pkg_repo/$CARCH
#export UNISON="/root/.unison"
export UNISON="/data/pkg_repo/.unison"
@@ -25,13 +26,13 @@ function sync_dirs {
echo " Updating $3 "
echo "________________________________________________________"
#first bring down new changes from knoppmyth.net
echo "--------"
echo
- echo "Syncing the packages with knoppmyth.net"
+ echo "Syncing the packages with linhes.org"
echo
echo "--------"
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE $LOCAL
if [ ! $? = 0 ]
then
@@ -47,11 +48,11 @@ function sync_dirs {
#push the database back
echo "--------"
echo
- echo "Pushing the pkg database to knoppmyth.net"
+ echo "Pushing the pkg database to linhes.org"
echo
echo "--------"
- unison km-up -logfile /tmp/unison-up.log -auto -batch -numericids -force $LOCAL $LOCAL ssh://reposync@knoppmyth.net/$REMOTE
- #scp $LOCAL/*.db.tar.gz reposync@knoppmyth.net:$REMOTE/
+ unison km-up -logfile /tmp/unison-up.log -auto -batch -numericids -force $LOCAL $LOCAL ssh://reposync@linhes.org/$REMOTE
+ #scp $LOCAL/*.db.tar.gz reposync@linhes.org:$REMOTE/
echo "-------------------------------------------------------"
echo "----------- Finished with $3 -----------"
@@ -64,30 +65,30 @@ function source_sync () {
case $1 in
testing )
echo "updating source packages"
- REMOTE_DIR=/mount/repository/repo/src_packages/core-testing
+ REMOTE_DIR=/srv/www/repo/src_packages/core-testing
LOCAL=/data/pkg_repo/src_packages/core-testing
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE_DIR $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE_DIR $LOCAL
- REMOTE_DIR=/mount/repository/repo/src_packages/extra-testing
+ REMOTE_DIR=/srv/www/repo/src_packages/extra-testing
LOCAL=/data/pkg_repo/src_packages/extra-testing
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE_DIR $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE_DIR $LOCAL
;;
release )
echo "updating source packages"
- REMOTE_DIR=/mount/repository/repo/src_packages/core
+ REMOTE_DIR=/srv/www/repo/src_packages/core
LOCAL=/data/pkg_repo/src_packages/core
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE_DIR $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE_DIR $LOCAL
- REMOTE_DIR=/mount/repository/repo/src_packages/extra
+ REMOTE_DIR=/srv/www/repo/src_packages/extra
LOCAL=/data/pkg_repo/src_packages/extra
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE_DIR $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE_DIR $LOCAL
;;
chroot-devel )
echo "updating source packages"
- REMOTE_DIR=/mount/repository/repo/src_packages/chroot-devel
+ REMOTE_DIR=/srv/www/repo/src_packages/chroot-devel
LOCAL=/data/pkg_repo/src_packages/chroot-devel
- unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@knoppmyth.net/$REMOTE_DIR $LOCAL
+ unison km-down -logfile /tmp/unison-down.log -auto -batch -numericids ssh://reposync@linhes.org/$REMOTE_DIR $LOCAL
;;
@@ -1,6 +1,6 @@
#!/bin/bash
-#This script will create and synchronize a local package mirror with the repository (as defined below) on knoppmyth.net, it will also update the database.
-#This script uses a shared account on knoppmyth.net. DO NOT change the account name
+#This script will create and synchronize a local package mirror with the repository (as defined below) on linhes.org, it will also update the database.
+#This script uses a shared account on linhes.org. DO NOT change the account name
# and dont' ask for the password, instead setup ssh keys.
#
@@ -25,13 +26,13 @@ function sync_dirs {
echo " Updating $3 "
echo "________________________________________________________"
- #first bring down new changes from knoppmyth.net
+ #first bring down new changes from linhes.org
echo "--------"
echo